=====
Usage
=====


Command Line Interface (CLI)
============================

Select the pattern to use

    tbt sort set pattern michel1



Sort current directory

    tbt sort .


This will give you the option to cancel if any problems are detected:

<EXAMPLE>

Python
======

To use trialbureautools in a project::

    import trialbureautools
